@@ -73,13 +73,14 @@ class APIRouter(base_wsgi.Router):
     def __init__(self, ext_mgr=None):
         if ext_mgr is None:
             if self.ExtensionManager:
+                # pylint: disable=not-callable
                 ext_mgr = self.ExtensionManager()
             else:
                 raise Exception(_("Must specify an ExtensionManager class"))
 
         mapper = ProjectMapper()
         self.resources = {}
-        self._setup_routes(mapper, ext_mgr)
+        self._setup_routes(mapper)
         self._setup_ext_routes(mapper, ext_mgr)
         self._setup_extensions(ext_mgr)
         super(APIRouter, self).__init__(mapper)
@@ -124,5 +125,5 @@ class APIRouter(base_wsgi.Router):
             resource.register_actions(controller)
             resource.register_extensions(controller)
 
-    def _setup_routes(self, mapper, ext_mgr):
+    def _setup_routes(self, mapper):
         raise NotImplementedError
