@@ -114,13 +114,33 @@ REST_API_VERSION_HISTORY = """
     * 2.40 - Added share group and share group snapshot quotas.
     * 2.41 - Added 'description' in share type create/list APIs.
     * 2.42 - Added ``with_count`` in share list API to get total count info.
+    * 2.43 - Added filter search by extra spec for share type list.
+    * 2.44 - Added 'ou' field to 'security_service' object.
+    * 2.45 - Added access metadata for share access and also introduced
+             the GET /share-access-rules API. The prior API to retrieve
+             access rules will not work with API version >=2.45.
+    * 2.46 - Added 'is_default' field to 'share_type' and 'share_group_type'
+             objects.
+    * 2.47 - Export locations for non-active share replicas are no longer
+             retrievable through the export locations APIs:
+             GET /v2/{tenant_id}/shares/{share_id}/export_locations and
+             GET /v2/{tenant_id}/shares/{share_id}/export_locations/{
+             export_location_id}. A new API is introduced at this
+             version: GET /v2/{tenant_id}/share-replicas/{
+             replica_id}/export-locations to allow retrieving individual
+             replica export locations if available.
+    * 2.48 - Added support for extra-spec "availability_zones" within Share
+             types along with validation in the API.
+    * 2.49 - Added Manage/Unmanage Share Server APIs. Updated Manage/Unmanage
+             Shares and Snapshots APIs to work in
+             ``driver_handles_shares_servers`` enabled mode.
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.42"
+_MAX_API_VERSION = "2.49"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
