@@ -15,10 +15,13 @@
 
 """The share type API controller module.."""
 
+import ast
+
 from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 import six
+from six.moves import http_client
 import webob
 from webob import exc
 
@@ -44,7 +47,7 @@ class ShareTypesController(wsgi.Controller):
     def __getattr__(self, key):
         if key == 'os-share-type-access':
             return self.share_type_access
-        return super(self.__class__, self).__getattr__(key)
+        return super(ShareTypesController, self).__getattribute__(key)
 
     def _notify_share_type_error(self, context, method, payload):
         rpc.get_notifier('shareType').error(context, method, payload)
@@ -122,6 +125,21 @@ class ShareTypesController(wsgi.Controller):
                 req.params.get('is_public'))
         else:
             filters['is_public'] = True
+
+        extra_specs = req.params.get('extra_specs', {})
+        extra_specs_disallowed = (req.api_version_request <
+                                  api_version.APIVersionRequest("2.43"))
+
+        if extra_specs and extra_specs_disallowed:
+            msg = _("Filter by 'extra_specs' is not supported by this "
+                    "microversion. Use 2.43 or greater microversion to "
+                    "be able to use filter search by 'extra_specs.")
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+        elif extra_specs:
+            extra_specs = ast.literal_eval(extra_specs)
+            filters['extra_specs'] = share_types.sanitize_extra_specs(
+                extra_specs)
+
         limited_types = share_types.get_all_types(
             context, search_opts=filters).values()
         return list(limited_types)
@@ -153,7 +171,7 @@ class ShareTypesController(wsgi.Controller):
 
     @wsgi.Controller.api_version("2.24")  # noqa
     @wsgi.action("create")
-    def create(self, req, body):  # pylint: disable=E0102
+    def create(self, req, body):  # pylint: disable=function-redefined
         return self._create(req, body, set_defaults=False)
 
     @wsgi.Controller.authorize('create')
@@ -250,7 +268,7 @@ class ShareTypesController(wsgi.Controller):
 
             raise webob.exc.HTTPNotFound()
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     @wsgi.Controller.authorize('list_project_access')
     def share_type_access(self, req, id):
@@ -267,13 +285,7 @@ class ShareTypesController(wsgi.Controller):
             expl = _("Access list not available for public share types.")
             raise webob.exc.HTTPNotFound(explanation=expl)
 
-        # TODO(vponomaryov): move to views.
-        rval = []
-        for project_id in share_type['projects']:
-            rval.append(
-                {'share_type_id': share_type['id'], 'project_id': project_id}
-            )
-        return {'share_type_access': rval}
+        return self._view_builder.share_type_access(req, share_type)
 
     @wsgi.action('addProjectAccess')
     @wsgi.Controller.authorize('add_project_access')
@@ -289,7 +301,7 @@ class ShareTypesController(wsgi.Controller):
         except exception.ShareTypeAccessExists as err:
             raise webob.exc.HTTPConflict(explanation=six.text_type(err))
 
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     @wsgi.action('removeProjectAccess')
     @wsgi.Controller.authorize('remove_project_access')
@@ -304,7 +316,7 @@ class ShareTypesController(wsgi.Controller):
             share_types.remove_share_type_access(context, id, project)
         except exception.ShareTypeAccessNotFound as err:
             raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
-        return webob.Response(status_int=202)
+        return webob.Response(status_int=http_client.ACCEPTED)
 
     def _verify_if_non_public_share_type(self, context, share_type_id):
         try:
