@@ -64,7 +64,7 @@ class VersionsRouter(openstack.APIRouter):
 
     ExtensionManager = extensions.ExtensionManager
 
-    def _setup_routes(self, mapper, ext_mgr):
+    def _setup_routes(self, mapper):
         self.resources['versions'] = create_resource()
         mapper.connect('versions', '/',
                        controller=self.resources['versions'],
@@ -86,7 +86,7 @@ class VersionsController(wsgi.Controller):
         return builder.build_versions(known_versions)
 
     @wsgi.Controller.api_version('2.0')  # noqa
-    def index(self, req):  # pylint: disable=E0102
+    def index(self, req):  # pylint: disable=function-redefined
         """Return versions supported after the start of microversions."""
         builder = views_versions.get_view_builder(req)
         known_versions = copy.deepcopy(_KNOWN_VERSIONS)
