@@ -459,6 +459,10 @@ class ManageInvalidShare(InvalidShare):
                 "invalid share: %(reason)s")
 
 
+class ManageShareServerError(ManilaException):
+    message = _("Manage existing share server failed due to: %(reason)s")
+
+
 class UnmanageInvalidShare(InvalidShare):
     message = _("Unmanage existing share failed due to "
                 "invalid share: %(reason)s")
@@ -472,6 +476,10 @@ class ShareAccessExists(ManilaException):
     message = _("Share access %(access_type)s:%(access)s exists.")
 
 
+class ShareAccessMetadataNotFound(NotFound):
+    message = _("Share access rule metadata does not exist.")
+
+
 class ShareSnapshotAccessExists(InvalidInput):
     message = _("Share snapshot access %(access_type)s:%(access)s exists.")
 
@@ -543,11 +551,11 @@ class ShareMetadataNotFound(NotFound):
     message = _("Metadata item is not found.")
 
 
-class InvalidShareMetadata(Invalid):
+class InvalidMetadata(Invalid):
     message = _("Invalid metadata.")
 
 
-class InvalidShareMetadataSize(Invalid):
+class InvalidMetadataSize(Invalid):
     message = _("Invalid metadata size.")
 
 
