@@ -69,9 +69,9 @@ class API(base.Base):
     def create(self, context, share_proto, size, name, description,
                snapshot_id=None, availability_zone=None, metadata=None,
                share_network_id=None, share_type=None, is_public=False,
-               share_group_id=None, share_group_snapshot_member=None):
+               share_group_id=None, share_group_snapshot_member=None,
+               availability_zones=None):
         """Create new share."""
-        policy.check_policy(context, 'share', 'create')
 
         self._check_metadata_properties(metadata)
 
@@ -168,11 +168,6 @@ class API(base.Base):
                                 'd_consumed': _consumed('shares')})
                 raise exception.ShareLimitExceeded(allowed=quotas['shares'])
 
-        try:
-            is_public = strutils.bool_from_string(is_public, strict=True)
-        except ValueError as e:
-            raise exception.InvalidParameterValue(six.text_type(e))
-
         share_group = None
         if share_group_id:
             try:
@@ -186,7 +181,7 @@ class API(base.Base):
                     'avail': constants.STATUS_AVAILABLE,
                     'status': share_group['status'],
                 }
-                msg = _("Share group status must be %(avail)s, got"
+                msg = _("Share group status must be %(avail)s, got "
                         "%(status)s.") % params
                 raise exception.InvalidShareGroup(message=msg)
 
@@ -257,7 +252,7 @@ class API(base.Base):
             context, share, share_network_id=share_network_id, host=host,
             availability_zone=availability_zone, share_group=share_group,
             share_group_snapshot_member=share_group_snapshot_member,
-            share_type_id=share_type_id)
+            share_type_id=share_type_id, availability_zones=availability_zones)
 
         # Retrieve the share with instance details
         share = self.db.share_get(context, share['id'])
@@ -333,15 +328,14 @@ class API(base.Base):
     def create_instance(self, context, share, share_network_id=None,
                         host=None, availability_zone=None,
                         share_group=None, share_group_snapshot_member=None,
-                        share_type_id=None):
-        policy.check_policy(context, 'share', 'create')
-
+                        share_type_id=None, availability_zones=None):
         request_spec, share_instance = (
             self.create_share_instance_and_get_request_spec(
                 context, share, availability_zone=availability_zone,
                 share_group=share_group, host=host,
                 share_network_id=share_network_id,
-                share_type_id=share_type_id))
+                share_type_id=share_type_id,
+                availability_zones=availability_zones))
 
         if share_group_snapshot_member:
             # Inherit properties from the share_group_snapshot_member
@@ -379,7 +373,8 @@ class API(base.Base):
     def create_share_instance_and_get_request_spec(
             self, context, share, availability_zone=None,
             share_group=None, host=None, share_network_id=None,
-            share_type_id=None, cast_rules_to_readonly=False):
+            share_type_id=None, cast_rules_to_readonly=False,
+            availability_zones=None):
 
         availability_zone_id = None
         if availability_zone:
@@ -449,6 +444,7 @@ class API(base.Base):
             'share_type': share_type,
             'share_group': share_group,
             'availability_zone_id': availability_zone_id,
+            'availability_zones': availability_zones,
         }
         return request_spec, share_instance
 
@@ -473,6 +469,21 @@ class API(base.Base):
                     "state.")
             raise exception.ReplicationException(reason=msg % share['id'])
 
+        share_type = share_types.get_share_type(
+            context, share.instance['share_type_id'])
+        type_azs = share_type['extra_specs'].get('availability_zones', '')
+        type_azs = [t for t in type_azs.split(',') if type_azs]
+        if (availability_zone and type_azs and
+                availability_zone not in type_azs):
+            msg = _("Share replica cannot be created since the share type "
+                    "%(type)s is not supported within the availability zone "
+                    "chosen %(az)s.")
+            type_name = '%s' % (share_type['name'] or '')
+            type_id = '(ID: %s)' % share_type['id']
+            payload = {'type': '%s%s' % (type_name, type_id),
+                       'az': availability_zone}
+            raise exception.InvalidShare(message=msg % payload)
+
         if share['replication_type'] == constants.REPLICATION_TYPE_READABLE:
             cast_rules_to_readonly = True
         else:
@@ -483,7 +494,9 @@ class API(base.Base):
                 context, share, availability_zone=availability_zone,
                 share_network_id=share_network_id,
                 share_type_id=share['instance']['share_type_id'],
-                cast_rules_to_readonly=cast_rules_to_readonly))
+                cast_rules_to_readonly=cast_rules_to_readonly,
+                availability_zones=type_azs)
+        )
 
         all_replicas = self.db.share_replicas_get_all_by_share(
             context, share['id'])
@@ -590,8 +603,6 @@ class API(base.Base):
         self.share_rpcapi.update_share_replica(context, share_replica)
 
     def manage(self, context, share_data, driver_options):
-        policy.check_policy(context, 'share', 'manage')
-
         shares = self.get_all(context, {
             'host': share_data['host'],
             'export_location': share_data['export_location'],
@@ -602,6 +613,36 @@ class API(base.Base):
         share_type_id = share_data['share_type_id']
         share_type = share_types.get_share_type(context, share_type_id)
 
+        share_server_id = share_data.get('share_server_id')
+
+        dhss = share_types.parse_boolean_extra_spec(
+            'driver_handles_share_servers',
+            share_type['extra_specs']['driver_handles_share_servers'])
+
+        if dhss and not share_server_id:
+            msg = _("Share Server ID parameter is required when managing a "
+                    "share using a share type with "
+                    "driver_handles_share_servers extra-spec set to True.")
+            raise exception.InvalidInput(reason=msg)
+        if not dhss and share_server_id:
+            msg = _("Share Server ID parameter is not expected when managing a"
+                    " share using a share type with "
+                    "driver_handles_share_servers extra-spec set to False.")
+            raise exception.InvalidInput(reason=msg)
+
+        if share_server_id:
+            try:
+                share_server = self.db.share_server_get(
+                    context, share_data['share_server_id'])
+            except exception.ShareServerNotFound:
+                msg = _("Share Server specified was not found.")
+                raise exception.InvalidInput(reason=msg)
+
+            if share_server['status'] != constants.STATUS_ACTIVE:
+                msg = _("Share Server specified is not active.")
+                raise exception.InvalidShareServer(message=msg)
+            share_data['share_network_id'] = share_server['share_network_id']
+
         share_data.update({
             'user_id': context.user_id,
             'project_id': context.project_id,
@@ -977,6 +1018,65 @@ class API(base.Base):
         # and server deletion.
         self.share_rpcapi.delete_share_server(context, server)
 
+    def manage_share_server(
+            self, context, identifier, host, share_network, driver_opts):
+        """Manage a share server."""
+
+        try:
+            matched_servers = self.db.share_server_search_by_identifier(
+                context, identifier)
+        except exception.ShareServerNotFound:
+            pass
+        else:
+            msg = _("Identifier %(identifier)s specified matches existing "
+                    "share servers: %(servers)s.") % {
+                'identifier': identifier,
+                'servers': ', '.join(s['identifier'] for s in matched_servers)
+            }
+            raise exception.InvalidInput(reason=msg)
+
+        values = {
+            'host': host,
+            'share_network_id': share_network['id'],
+            'status': constants.STATUS_MANAGING,
+            'is_auto_deletable': False,
+            'identifier': identifier,
+        }
+
+        server = self.db.share_server_create(context, values)
+
+        self.share_rpcapi.manage_share_server(
+            context, server, identifier, driver_opts)
+
+        return self.db.share_server_get(context, server['id'])
+
+    def unmanage_share_server(self, context, share_server, force=False):
+        """Unmanage a share server."""
+
+        shares = self.db.share_instances_get_all_by_share_server(
+            context, share_server['id'])
+
+        if shares:
+            raise exception.ShareServerInUse(
+                share_server_id=share_server['id'])
+
+        share_groups = self.db.share_group_get_all_by_share_server(
+            context, share_server['id'])
+        if share_groups:
+            LOG.error("share server '%(ssid)s' in use by share groups.",
+                      {'ssid': share_server['id']})
+            raise exception.ShareServerInUse(
+                share_server_id=share_server['id'])
+
+        update_data = {'status': constants.STATUS_UNMANAGING,
+                       'terminated_at': timeutils.utcnow()}
+
+        share_server = self.db.share_server_update(
+            context, share_server['id'], update_data)
+
+        self.share_rpcapi.unmanage_share_server(
+            context, share_server, force=force)
+
     def create_snapshot(self, context, share, name, description,
                         force=False):
         policy.check_policy(context, 'share', 'create_snapshot', share)
@@ -1197,6 +1297,20 @@ class API(base.Base):
         service = self.db.service_get_by_args(
             context, dest_host_host, 'manila-share')
 
+        type_azs = share_type['extra_specs'].get('availability_zones', '')
+        type_azs = [t for t in type_azs.split(',') if type_azs]
+        if type_azs and service['availability_zone']['name'] not in type_azs:
+            msg = _("Share %(shr)s cannot be migrated to host %(dest)s "
+                    "because share type %(type)s is not supported within the "
+                    "availability zone (%(az)s) that the host is in.")
+            type_name = '%s' % (share_type['name'] or '')
+            type_id = '(ID: %s)' % share_type['id']
+            payload = {'type': '%s%s' % (type_name, type_id),
+                       'az': service['availability_zone']['name'],
+                       'shr': share['id'],
+                       'dest': dest_host}
+            raise exception.InvalidShare(reason=msg % payload)
+
         request_spec = self._get_request_spec_dict(
             share,
             share_type,
@@ -1448,12 +1562,6 @@ class API(base.Base):
 
     @policy.wrap_check_policy('share')
     def update(self, context, share, fields):
-        if 'is_public' in fields:
-            try:
-                fields['is_public'] = strutils.bool_from_string(
-                    fields['is_public'], strict=True)
-            except ValueError as e:
-                raise exception.InvalidParameterValue(six.text_type(e))
         return self.db.share_update(context, share['id'], fields)
 
     @policy.wrap_check_policy('share')
@@ -1497,10 +1605,6 @@ class API(base.Base):
                 msg = _("Wrong extra specs filter provided: "
                         "%s.") % six.text_type(filters['extra_specs'])
                 raise exception.InvalidInput(reason=msg)
-        if 'limit' in search_opts:
-            filters['limit'] = search_opts.pop('limit')
-        if 'offset' in search_opts:
-            filters['offset'] = search_opts.pop('offset')
         if not (isinstance(sort_key, six.string_types) and sort_key):
             msg = _("Wrong sort_key filter provided: "
                     "'%s'.") % six.text_type(sort_key)
