@@ -23,6 +23,7 @@ from oslo_utils import netutils
 
 storops = importutils.try_import('storops')
 if storops:
+    # pylint: disable=import-error
     from storops import exception as storops_ex
     from storops.unity import enums
 
@@ -36,10 +37,7 @@ from manila.share.drivers.dell_emc.plugins.unity import utils as unity_utils
 from manila.share import utils as share_utils
 from manila import utils
 
-VERSION = "4.0.1"
-"""Version history:
-     4.0.1 - Fix parsing management IPv6 address
-"""
+VERSION = "6.1.0"
 
 LOG = log.getLogger(__name__)
 SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
@@ -89,6 +87,8 @@ class UnityStorageConnection(driver.StorageConnection):
         self.max_over_subscription_ratio = None
         self.port_ids_conf = None
         self.ipv6_implemented = True
+        self.revert_to_snap_support = True
+        self.shrink_share_support = True
 
         # props from super class.
         self.driver_handles_share_servers = True
@@ -96,8 +96,7 @@ class UnityStorageConnection(driver.StorageConnection):
     def connect(self, emc_share_driver, context):
         """Connect to Unity storage."""
         config = emc_share_driver.configuration
-        storage_ip = enas_utils.convert_ipv6_format_if_needed(
-            config.emc_nas_server)
+        storage_ip = config.emc_nas_server
         username = config.emc_nas_login
         password = config.emc_nas_password
         self.client = client.UnityClient(storage_ip, username, password)
@@ -272,6 +271,29 @@ class UnityStorageConnection(driver.StorageConnection):
             raise exception.ShareExtendingError(share_id=share_id,
                                                 reason=reason)
 
+    def shrink_share(self, share, new_size, share_server=None):
+        """Shrinks a share to new size.
+
+        :param share: Share that will be shrunk.
+        :param new_size: New size of share.
+        :param share_server: Data structure with share server information.
+            Not used by this driver.
+        """
+        share_id = share['id']
+        backend_share = self.client.get_share(share_id,
+                                              share['share_proto'])
+        if self._is_share_from_snapshot(backend_share):
+            reason = ("Driver does not support shrinking a "
+                      "snapshot based share.")
+            raise exception.ShareShrinkingError(share_id=share_id,
+                                                reason=reason)
+        self.client.shrink_filesystem(share_id, backend_share.filesystem,
+                                      new_size)
+        LOG.info("Share %(shr_id)s successfully shrunk to "
+                 "%(shr_size)sG.",
+                 {'shr_id': share_id,
+                  'shr_size': new_size})
+
     def create_snapshot(self, context, snapshot, share_server=None):
         """Create snapshot from share."""
         share_name = snapshot['share_id']
@@ -682,3 +704,8 @@ class UnityStorageConnection(driver.StorageConnection):
             raise exception.InvalidShare(
                 reason=(_('Invalid NAS protocol supplied: %s.') %
                         share_proto))
+
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, share_server=None):
+        """Reverts a share (in place) to the specified snapshot."""
+        return self.client.restore_snapshot(snapshot['id'])
