@@ -24,18 +24,18 @@ import six
 
 from manila.common import constants as const
 from manila import exception
-from manila.i18n import _, _LE, _LI, _LW
-from manila.share.drivers.dell_emc.plugins.vnx import connector
-from manila.share.drivers.dell_emc.plugins.vnx import constants
-from manila.share.drivers.dell_emc.plugins.vnx import utils as vnx_utils
-from manila.share.drivers.dell_emc.plugins.vnx import xml_api_parser as parser
+from manila.i18n import _
+from manila.share.drivers.dell_emc.common.enas import connector
+from manila.share.drivers.dell_emc.common.enas import constants
+from manila.share.drivers.dell_emc.common.enas import utils as enas_utils
+from manila.share.drivers.dell_emc.common.enas import xml_api_parser as parser
 from manila import utils
 
 LOG = log.getLogger(__name__)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class StorageObjectManager(object):
     def __init__(self, configuration):
         self.context = dict()
@@ -47,7 +47,7 @@ class StorageObjectManager(object):
         elt_maker = builder.ElementMaker(nsmap={None: constants.XML_NAMESPACE})
         xml_parser = parser.XMLAPIParser()
 
-        obj_types = StorageObject.__subclasses__()  # pylint: disable=E1101
+        obj_types = StorageObject.__subclasses__()  # pylint: disable=no-member
         for item in obj_types:
             key = item.__name__
             self.context[key] = eval(key)(self.connectors,
@@ -89,8 +89,8 @@ class StorageObject(object):
                                        constants.STATUS_INFO):
             response['maxSeverity'] = constants.STATUS_OK
 
-            LOG.warning(_LW("Translated status from %(old)s to %(new)s. "
-                            "Message: %(info)s."),
+            LOG.warning("Translated status from %(old)s to %(new)s. "
+                        "Message: %(info)s.",
                         {'old': old_Severity,
                          'new': response['maxSeverity'],
                          'info': response})
@@ -166,7 +166,7 @@ class StorageObject(object):
         """Execute NAS command via SSH.
 
         :param retry_patterns: list of tuples,where each tuple contains a reg
-            expression and a exception.
+            expression and an exception.
         :param check_exit_code: Boolean. Raise
             processutils.ProcessExecutionError if the command failed to
             execute and this parameter is set to True.
@@ -181,7 +181,7 @@ class StorageObject(object):
                 if re.search(pattern[0], e.stdout):
                     raise pattern[1]
 
-            raise e
+            raise
 
         return out, err
 
@@ -211,8 +211,8 @@ class StorageObject(object):
         return self.manager.getStorageContext(type)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class FileSystem(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(FileSystem, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -252,8 +252,8 @@ class FileSystem(StorageObject):
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._response_validation(
                 response, constants.MSG_FILESYSTEM_EXIST):
-            LOG.warning(_LW("File system %s already exists. "
-                            "Skip the creation."), name)
+            LOG.warning("File system %s already exists. "
+                        "Skip the creation.", name)
             return
         elif constants.STATUS_OK != response['maxSeverity']:
             message = (_("Failed to create file system %(name)s. "
@@ -306,7 +306,7 @@ class FileSystem(StorageObject):
     def delete(self, name):
         status, out = self.get(name)
         if constants.STATUS_NOT_FOUND == status:
-            LOG.warning(_LW("File system %s not found. Skip the deletion."),
+            LOG.warning("File system %s not found. Skip the deletion.",
                         name)
             return
         elif constants.STATUS_OK != status:
@@ -440,8 +440,8 @@ class FileSystem(StorageObject):
         try:
             self._execute_cmd(copy_ckpt_cmd, check_exit_code=True)
         except processutils.ProcessExecutionError:
-            LOG.exception(_LE("Failed to copy content from snapshot %(snap)s "
-                              "to file system %(filesystem)s."),
+            LOG.exception("Failed to copy content from snapshot %(snap)s "
+                          "to file system %(filesystem)s.",
                           {'snap': snap_name,
                            'filesystem': name})
 
@@ -479,8 +479,8 @@ class FileSystem(StorageObject):
         self._execute_cmd(rw_mount_cmd)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class StoragePool(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(StoragePool, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -541,8 +541,8 @@ class StoragePool(StorageObject):
         return out['id']
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class MountPoint(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(MountPoint, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -575,8 +575,8 @@ class MountPoint(StorageObject):
             self.xml_retry = True
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._is_mount_point_already_existent(response):
-            LOG.warning(_LW("Mount Point %(mount)s already exists. "
-                            "Skip the creation."), {'mount': mount_path})
+            LOG.warning("Mount Point %(mount)s already exists. "
+                        "Skip the creation.", {'mount': mount_path})
             return
         elif constants.STATUS_OK != response['maxSeverity']:
             message = (_('Failed to create Mount Point %(mount)s for '
@@ -641,8 +641,8 @@ class MountPoint(StorageObject):
             self.xml_retry = True
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._is_mount_point_nonexistent(response):
-            LOG.warning(_LW('Mount point %(mount)s on mover %(mover_name)s '
-                            'not found.'),
+            LOG.warning('Mount point %(mount)s on mover %(mover_name)s '
+                        'not found.',
                         {'mount': mount_path, 'mover_name': mover_name})
 
             return
@@ -682,8 +682,8 @@ class MountPoint(StorageObject):
         return False
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class Mover(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(Mover, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -816,8 +816,8 @@ class Mover(StorageObject):
         lines = out.strip().split('\n')
         for line in lines:
             if line.strip().split() == header:
-                LOG.info(_LI('Found the header of the command '
-                             '/nas/bin/nas_cel -interconnect -l.'))
+                LOG.info('Found the header of the command '
+                         '/nas/bin/nas_cel -interconnect -l.')
             else:
                 interconn = line.strip().split()
                 if interconn[2] == source and interconn[4] == destination:
@@ -847,8 +847,8 @@ class Mover(StorageObject):
         return physical_network_devices
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class VDM(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(VDM, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -873,7 +873,7 @@ class VDM(StorageObject):
             self.xml_retry = True
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._response_validation(response, constants.MSG_VDM_EXIST):
-            LOG.warning(_LW("VDM %(name)s already exists. Skip the creation."),
+            LOG.warning("VDM %(name)s already exists. Skip the creation.",
                         {'name': name})
         elif constants.STATUS_OK != response['maxSeverity']:
             message = (_("Failed to create VDM %(name)s on mover "
@@ -917,7 +917,7 @@ class VDM(StorageObject):
     def delete(self, name):
         status, out = self.get(name)
         if constants.STATUS_NOT_FOUND == status:
-            LOG.warning(_LW("VDM %s not found. Skip the deletion."),
+            LOG.warning("VDM %s not found. Skip the deletion.",
                         name)
             return
         elif constants.STATUS_OK != status:
@@ -1022,8 +1022,8 @@ class VDM(StorageObject):
         return interfaces
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class Snapshot(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(Snapshot, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -1053,8 +1053,8 @@ class Snapshot(StorageObject):
         response = self._send_request(request)
 
         if self._response_validation(response, constants.MSG_SNAP_EXIST):
-            LOG.warning(_LW("Snapshot %(name)s already exists. "
-                            "Skip the creation."),
+            LOG.warning("Snapshot %(name)s already exists. "
+                        "Skip the creation.",
                         {'name': name})
         elif constants.STATUS_OK != response['maxSeverity']:
             message = (_("Failed to create snapshot %(name)s on "
@@ -1098,7 +1098,7 @@ class Snapshot(StorageObject):
     def delete(self, name):
         status, out = self.get(name)
         if constants.STATUS_NOT_FOUND == status:
-            LOG.warning(_LW("Snapshot %s not found. Skip the deletion."),
+            LOG.warning("Snapshot %s not found. Skip the deletion.",
                         name)
             return
         elif constants.STATUS_OK != status:
@@ -1137,8 +1137,8 @@ class Snapshot(StorageObject):
         return self.snap_map[name]['id']
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class MoverInterface(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(MoverInterface, self).__init__(conn, elt_maker, xml_parser,
@@ -1159,18 +1159,21 @@ class MoverInterface(StorageObject):
 
         mover_id = self._get_mover_id(mover_name, False)
 
+        params = dict(device=device_name,
+                      ipAddress=six.text_type(ip_addr),
+                      mover=mover_id,
+                      name=name,
+                      netMask=net_mask,
+                      vlanid=six.text_type(vlan_id))
+
+        if interface.get('ip_version') == 6:
+            params['ipVersion'] = 'IPv6'
+
         if self.xml_retry:
             self.xml_retry = False
 
         request = self._build_task_package(
-            self.elt_maker.NewMoverInterface(
-                device=device_name,
-                ipAddress=six.text_type(ip_addr),
-                mover=mover_id,
-                name=name,
-                netMask=net_mask,
-                vlanid=six.text_type(vlan_id)
-            )
+            self.elt_maker.NewMoverInterface(**params)
         )
 
         response = self._send_request(request)
@@ -1182,18 +1185,18 @@ class MoverInterface(StorageObject):
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._response_validation(
                 response, constants.MSG_INTERFACE_NAME_EXIST):
-            LOG.warning(_LW("Mover interface name %s already exists. "
-                            "Skip the creation."), name)
+            LOG.warning("Mover interface name %s already exists. "
+                        "Skip the creation.", name)
             return
         elif self._response_validation(
                 response, constants.MSG_INTERFACE_EXIST):
-            LOG.warning(_LW("Mover interface IP %s already exists. "
-                            "Skip the creation."), ip_addr)
+            LOG.warning("Mover interface IP %s already exists. "
+                        "Skip the creation.", ip_addr)
             return
         elif self._response_validation(
                 response, constants.MSG_INTERFACE_INVALID_VLAN_ID):
             # When fail to create a mover interface with the specified
-            # vlan id, VNX will leave a interface with vlan id 0 in the
+            # vlan id, VNX will leave an interface with vlan id 0 in the
             # backend. So we should explicitly remove the interface.
             try:
                 self.delete(six.text_type(ip_addr), mover_name)
@@ -1248,8 +1251,8 @@ class MoverInterface(StorageObject):
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif self._response_validation(
                 response, constants.MSG_INTERFACE_NON_EXISTENT):
-            LOG.warning(_LW("Mover interface %s not found. "
-                            "Skip the deletion."), ip_addr)
+            LOG.warning("Mover interface %s not found. "
+                        "Skip the deletion.", ip_addr)
             return
         elif constants.STATUS_OK != response['maxSeverity']:
             message = (_("Failed to delete mover interface %(ip)s on mover "
@@ -1261,8 +1264,8 @@ class MoverInterface(StorageObject):
             raise exception.EMCVnxXMLAPIError(err=message)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class DNSDomain(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(DNSDomain, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -1318,13 +1321,13 @@ class DNSDomain(StorageObject):
             self.xml_retry = True
             raise exception.EMCVnxInvalidMoverID(id=mover_id)
         elif constants.STATUS_OK != response['maxSeverity']:
-            LOG.warning(_LW("Failed to delete DNS domain %(name)s. "
-                            "Reason: %(err)s."),
+            LOG.warning("Failed to delete DNS domain %(name)s. "
+                        "Reason: %(err)s.",
                         {'name': name, 'err': response['problems']})
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class CIFSServer(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(CIFSServer, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -1510,13 +1513,13 @@ class CIFSServer(StorageObject):
             status, out = self.get(
                 computer_name.lower(), mover_name, is_vdm, self.xml_retry)
             if constants.STATUS_NOT_FOUND == status:
-                LOG.warning(_LW("CIFS server %(name)s on mover %(mover_name)s "
-                                "not found. Skip the deletion."),
+                LOG.warning("CIFS server %(name)s on mover %(mover_name)s "
+                            "not found. Skip the deletion.",
                             {'name': computer_name, 'mover_name': mover_name})
                 return
         except exception.EMCVnxXMLAPIError:
-            LOG.warning(_LW("CIFS server %(name)s on mover %(mover_name)s "
-                            "not found. Skip the deletion."),
+            LOG.warning("CIFS server %(name)s on mover %(mover_name)s "
+                        "not found. Skip the deletion.",
                         {'name': computer_name, 'mover_name': mover_name})
             return
 
@@ -1544,8 +1547,8 @@ class CIFSServer(StorageObject):
         self.cifs_server_map[mover_name].pop(computer_name)
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class CIFSShare(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(CIFSShare, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -1608,7 +1611,7 @@ class CIFSShare(StorageObject):
     def delete(self, name, mover_name, is_vdm=True):
         status, out = self.get(name)
         if constants.STATUS_NOT_FOUND == status:
-            LOG.warning(_LW("CIFS share %s not found. Skip the deletion."),
+            LOG.warning("CIFS share %s not found. Skip the deletion.",
                         name)
             return
         elif constants.STATUS_OK != status:
@@ -1686,8 +1689,8 @@ class CIFSShare(StorageObject):
             dup_msg = re.compile(r'ACE for %(domain)s\\%(user)s unchanged' %
                                  {'domain': domain, 'user': user_name}, re.I)
             if re.search(dup_msg, expt.stdout):
-                LOG.warning(_LW("Duplicate access control entry, "
-                                "skipping allow..."))
+                LOG.warning("Duplicate access control entry, "
+                            "skipping allow...")
             else:
                 message = (_('Failed to allow the access %(access)s to '
                              'CIFS share %(name)s. Reason: %(err)s.') %
@@ -1718,10 +1721,10 @@ class CIFSShare(StorageObject):
                 % {'domain': domain, 'user': user_name}, re.I)
 
             if re.search(not_found_msg, expt.stdout):
-                LOG.warning(_LW("No access control entry found, "
-                                "skipping deny..."))
+                LOG.warning("No access control entry found, "
+                            "skipping deny...")
             elif re.search(user_err_msg, expt.stdout):
-                LOG.warning(_LW("User not found on domain, skipping deny..."))
+                LOG.warning("User not found on domain, skipping deny...")
             else:
                 message = (_('Failed to deny the access %(access)s to '
                              'CIFS share %(name)s. Reason: %(err)s.') %
@@ -1771,8 +1774,8 @@ class CIFSShare(StorageObject):
         return users_to_remove
 
 
-@vnx_utils.decorate_all_methods(vnx_utils.log_enter_exit,
-                                debug_only=True)
+@enas_utils.decorate_all_methods(enas_utils.log_enter_exit,
+                                 debug_only=True)
 class NFSShare(StorageObject):
     def __init__(self, conn, elt_maker, xml_parser, manager):
         super(NFSShare, self).__init__(conn, elt_maker, xml_parser, manager)
@@ -1800,7 +1803,7 @@ class NFSShare(StorageObject):
 
         status, out = self.get(name, mover_name)
         if constants.STATUS_NOT_FOUND == status:
-            LOG.warning(_LW("NFS share %s not found. Skip the deletion."),
+            LOG.warning("NFS share %s not found. Skip the deletion.",
                         path)
             return
 
@@ -1851,7 +1854,7 @@ class NFSShare(StorageObject):
             dup_msg = (r'%(mover_name)s : No such file or directory' %
                        {'mover_name': mover_name})
             if re.search(dup_msg, expt.stdout):
-                LOG.warning(_LW("NFS share %s not found."), name)
+                LOG.warning("NFS share %s not found.", name)
                 return constants.STATUS_NOT_FOUND, None
             else:
                 message = (_('Failed to list NFS share %(name)s on '
@@ -1872,13 +1875,14 @@ class NFSShare(StorageObject):
             for field in fields:
                 field = field.strip()
                 if field.startswith('rw='):
-                    nfs_share['RwHosts'] = field[3:].split(":")
+                    nfs_share['RwHosts'] = enas_utils.parse_ipaddr(field[3:])
                 elif field.startswith('access='):
-                    nfs_share['AccessHosts'] = field[7:].split(":")
+                    nfs_share['AccessHosts'] = enas_utils.parse_ipaddr(
+                        field[7:])
                 elif field.startswith('root='):
-                    nfs_share['RootHosts'] = field[5:].split(":")
+                    nfs_share['RootHosts'] = enas_utils.parse_ipaddr(field[5:])
                 elif field.startswith('ro='):
-                    nfs_share['RoHosts'] = field[3:].split(":")
+                    nfs_share['RoHosts'] = enas_utils.parse_ipaddr(field[3:])
 
             self.nfs_share_map[name] = nfs_share
         else:
@@ -1899,6 +1903,9 @@ class NFSShare(StorageObject):
             changed = False
             rwhosts = share['RwHosts']
             rohosts = share['RoHosts']
+
+            host_ip = enas_utils.convert_ipv6_format_if_needed(host_ip)
+
             if access_level == const.ACCESS_LEVEL_RW:
                 if host_ip not in rwhosts:
                     rwhosts.append(host_ip)
@@ -1942,7 +1949,6 @@ class NFSShare(StorageObject):
         do_allow_access(share_name, host_ip, mover_name, access_level)
 
     def deny_share_access(self, share_name, host_ip, mover_name):
-
         @utils.synchronized('emc-shareaccess-' + share_name)
         def do_deny_access(share_name, host_ip, mover_name):
             status, share = self.get(share_name, mover_name)
