@@ -17,6 +17,7 @@ Share driver for QNAP Storage.
 This driver supports QNAP Storage for NFS.
 """
 import datetime
+import math
 import re
 import time
 
@@ -70,9 +71,17 @@ class QnapShareDriver(driver.ShareDriver):
         1.0.3 - Add supports for Thin Provisioning, SSD Cache, Deduplication
                 and Compression.
         1.0.4 - Add support for QES fw 2.0.0.
+        1.0.5 - Fix bug #1773761, when user tries to manage share, the size
+                of managed share should not be changed.
+        1.0.6 - Add support for QES fw 2.1.0.
+        1.0.7 - Add support for QES fw on TDS series NAS model.
+        1.0.8 - Fix bug, driver should not manage snapshot which does not
+                exist in NAS.
+                Fix bug, driver should create share from snapshot with
+                specified size.
     """
 
-    DRIVER_VERSION = '1.0.4'
+    DRIVER_VERSION = '1.0.8'
 
     def __init__(self, *args, **kwargs):
         """Initialize QnapShareDriver."""
@@ -127,10 +136,10 @@ class QnapShareDriver(driver.ShareDriver):
         model_type = matches.group(1)
 
         ts_model_types = (
-            "TS", "SS", "IS", "TVS", "TDS", "TBS"
+            "TS", "SS", "IS", "TVS", "TBS"
         )
         tes_model_types = (
-            "TES",
+            "TES", "TDS"
         )
         es_model_types = (
             "ES",
@@ -161,14 +170,14 @@ class QnapShareDriver(driver.ShareDriver):
                         username=self.configuration.qnap_nas_login,
                         password=self.configuration.qnap_nas_password,
                         management_url=self.configuration.qnap_management_url)
-            elif "1.1.2" <= fw_version <= "2.0.9999":
+            elif "1.1.2" <= fw_version <= "2.1.9999":
                 LOG.debug('Create ES API Executor')
                 return api.QnapAPIExecutor(
                     username=self.configuration.qnap_nas_login,
                     password=self.configuration.qnap_nas_password,
                     management_url=self.configuration.qnap_management_url)
         elif model_type in es_model_types:
-            if "1.1.2" <= fw_version <= "2.0.9999":
+            if "1.1.2" <= fw_version <= "2.1.9999":
                 LOG.debug('Create ES API Executor')
                 return api.QnapAPIExecutor(
                     username=self.configuration.qnap_nas_login,
@@ -275,7 +284,7 @@ class QnapShareDriver(driver.ShareDriver):
                 'driver_handles_share_servers'),
             'pools': [single_pool],
         }
-        super(self.__class__, self)._update_share_stats(data)
+        super(QnapShareDriver, self)._update_share_stats(data)
 
     @utils.retry(exception=exception.ShareBackendException,
                  interval=3,
@@ -533,7 +542,8 @@ class QnapShareDriver(driver.ShareDriver):
             msg = _("Failed to create an unused share name.")
             raise exception.ShareBackendException(msg=msg)
 
-        self.api_executor.clone_snapshot(snapshot_id, create_share_name)
+        self.api_executor.clone_snapshot(snapshot_id,
+                                         create_share_name, share['size'])
 
         create_volID = ""
         created_share = self.api_executor.get_share_info(
@@ -546,10 +556,6 @@ class QnapShareDriver(driver.ShareDriver):
             msg = _("Failed to clone a snapshot in time.")
             raise exception.ShareBackendException(msg=msg)
 
-        snap_share = self.share_api.get(
-            context, snapshot['share_instance']['share_id'])
-        LOG.debug('snap_share[size]: %s', snap_share['size'])
-
         thin_provision = self.private_storage.get(
             snapshot['share_instance_id'], 'thin_provision')
         compression = self.private_storage.get(
@@ -567,19 +573,6 @@ class QnapShareDriver(driver.ShareDriver):
                    'deduplication': deduplication,
                    'ssd_cache': ssd_cache})
 
-        if (share['size'] > snap_share['size']):
-            share_dict = {
-                'sharename': create_share_name,
-                'old_sharename': create_share_name,
-                'new_size': share['size'],
-                'thin_provision': thin_provision == 'True',
-                'compression': compression == 'True',
-                'deduplication': deduplication == 'True',
-                'ssd_cache': ssd_cache == 'True',
-                'share_proto': share['share_proto']
-            }
-            self.api_executor.edit_share(share_dict)
-
         # Use private_storage to record volume ID and Name created in the NAS.
         _metadata = {
             'volID': create_volID,
@@ -664,8 +657,8 @@ class QnapShareDriver(driver.ShareDriver):
         access_level = access['access_level']
         access_to = access['access_to']
         LOG.debug('share_proto: %(share_proto)s '
-                  'access_type: %(access_type)s'
-                  'access_level: %(access_level)s'
+                  'access_type: %(access_type)s '
+                  'access_level: %(access_level)s '
                   'access_to: %(access_to)s',
                   {'share_proto': share_proto,
                    'access_type': access_type,
@@ -721,8 +714,8 @@ class QnapShareDriver(driver.ShareDriver):
         access_level = access['access_level']
         access_to = access['access_to']
         LOG.debug('share_proto: %(share_proto)s '
-                  'access_type: %(access_type)s'
-                  'access_level: %(access_level)s'
+                  'access_type: %(access_type)s '
+                  'access_level: %(access_level)s '
                   'access_to: %(access_to)s',
                   {'share_proto': share_proto,
                    'access_type': access_type,
@@ -778,7 +771,7 @@ class QnapShareDriver(driver.ShareDriver):
         """Manages a share that exists on backend."""
         if share['share_proto'].lower() == 'nfs':
             # 10.0.0.1:/share/example
-            LOG.info("Share %(shr_path)s will be managed with ID"
+            LOG.info("Share %(shr_path)s will be managed with ID "
                      "%(shr_id)s.",
                      {'shr_path': share['export_locations'][0]['path'],
                       'shr_id': share['id']})
@@ -837,12 +830,11 @@ class QnapShareDriver(driver.ShareDriver):
 
         vol_no = existing_share.find('vol_no').text
         vol = self.api_executor.get_specific_volinfo(vol_no)
-        vol_size_gb = int(vol.find('size').text) / units.Gi
+        vol_size_gb = math.ceil(float(vol.find('size').text) / units.Gi)
 
         share_dict = {
             'sharename': share_name,
             'old_sharename': share_name,
-            'new_size': vol_size_gb,
             'thin_provision': qnap_thin_provision,
             'compression': qnap_compression,
             'deduplication': qnap_deduplication,
@@ -896,6 +888,7 @@ class QnapShareDriver(driver.ShareDriver):
 
         if len(snapshot_id_info) == 2:
             share_name = snapshot_id_info[0]
+            snapshot_name = snapshot_id_info[1]
         else:
             msg = _("Incorrect provider_location format. It should have the "
                     "following format: share_name@snapshot_name.")
@@ -910,10 +903,24 @@ class QnapShareDriver(driver.ShareDriver):
             LOG.error(msg)
             raise exception.ShareNotFound(reason=msg)
 
+        check_snapshot = self.api_executor.get_snapshot_info(
+            volID=volID, snapshot_name=snapshot_name)
+        if check_snapshot is None:
+            msg = (_("The snapshot %(snapshot_name)s was not "
+                     "found on backend.") %
+                   {'snapshot_name': snapshot_name})
+            LOG.error(msg)
+            raise exception.InvalidParameterValue(err=msg)
+
         _metadata = {
             'snapshot_id': snapshot_id,
         }
         self.private_storage.update(snapshot['id'], _metadata)
+        parent_size = check_snapshot.find('parent_size')
+        snap_size_gb = None
+        if parent_size is not None:
+            snap_size_gb = math.ceil(float(parent_size.text) / units.Gi)
+        return {'size': snap_size_gb}
 
     def unmanage_snapshot(self, snapshot):
         """Remove the specified snapshot from Manila management."""
