@@ -22,22 +22,22 @@ import webob.dec
 import webob.request
 
 from manila.api import common as api_common
-from manila.api.middleware import auth
-from manila.api.middleware import fault
 from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi as os_wsgi
 from manila.api import urlmap
-from manila.api.v1 import limits
 from manila.api.v1 import router as router_v1
 from manila.api.v2 import router as router_v2
-from manila.api import versions
 from manila.common import constants
 from manila import context
 from manila import exception
 
 
+CONTEXT = context.get_admin_context()
+driver_opts = {}
 FAKE_UUID = 'aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa'
 FAKE_UUIDS = {}
+host = 'host_name'
+identifier = '7cf7c200-d3af-4e05-b87e-9167c95dfcad'
 
 
 class Context(object):
@@ -61,31 +61,6 @@ def fake_wsgi(self, req):
     return self.application
 
 
-def wsgi_app(inner_app_v2=None, fake_auth=True, fake_auth_context=None,
-             use_no_auth=False, ext_mgr=None):
-    if not inner_app_v2:
-        inner_app_v2 = router_v2.APIRouter(ext_mgr)
-
-    if fake_auth:
-        if fake_auth_context is not None:
-            ctxt = fake_auth_context
-        else:
-            ctxt = context.RequestContext('fake', 'fake', auth_token=True)
-        api_v2 = fault.FaultWrapper(auth.InjectContext(ctxt,
-                                                       inner_app_v2))
-    elif use_no_auth:
-        api_v2 = fault.FaultWrapper(auth.NoAuthMiddleware(
-            limits.RateLimitingMiddleware(inner_app_v2)))
-    else:
-        api_v2 = fault.FaultWrapper(auth.AuthMiddleware(
-            limits.RateLimitingMiddleware(inner_app_v2)))
-
-    mapper = urlmap.URLMap()
-    mapper['/v2'] = api_v2
-    mapper['/'] = fault.FaultWrapper(versions.Versions())
-    return mapper
-
-
 class FakeToken(object):
     id_count = 0
 
@@ -95,6 +70,7 @@ class FakeToken(object):
     def __init__(self, **kwargs):
         FakeToken.id_count += 1
         self.id = FakeToken.id_count
+        self.token_hash = None
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -294,6 +270,20 @@ fixture_valid_reset_status_body = (
     ({'reset_status': {'status': 'migrating_to'}}, '2.7'),
 )
 
+share_network_id = '5dfe0898-e2a1-4740-9177-81c7d26713b0'
+share_network = {
+    'name': 'share-net-fake',
+    'share_network_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0',
+    'project_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0'
+}
+SHARE_SERVER = {
+    'share_network': share_network,
+    'share_network_id': 'c5b3a865-56d0-4d88-abe5-879965e099c9',
+    'host': host,
+    'id': 'c39bb9ae-16a5-40f2-a24f-1cf3f549d3d3',
+    'status': constants.STATUS_ACTIVE
+}
+
 
 def mock_fake_admin_check(context, resource_name, action, *args, **kwargs):
     if context.is_admin:
