@@ -57,6 +57,13 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'delete', stubs.stub_share_delete)
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get)
+        self.mock_object(share_types, 'get_share_type',
+                         stubs.stub_share_type_get)
+        self.mock_object(
+            common, 'validate_public_share_policy',
+            mock.Mock(side_effect=lambda *args, **kwargs: args[1]))
+        self.resource_name = self.controller.resource_name
+        self.mock_policy_check = self.mock_object(policy, 'check_policy')
         self.maxDiff = None
         self.share = {
             "size": 100,
@@ -140,6 +147,8 @@ class ShareAPITest(test.TestCase):
 
         res_dict = self.controller.create(req, body)
 
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(self.share)
         expected['share'].pop('snapshot_support')
         self.assertEqual(expected, res_dict)
@@ -152,6 +161,8 @@ class ShareAPITest(test.TestCase):
 
         res_dict = self.controller.create(req, body)
 
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(self.share)
         self.assertEqual(expected, res_dict)
 
@@ -165,6 +176,8 @@ class ShareAPITest(test.TestCase):
         req = fakes.HTTPRequest.blank('/shares')
         res_dict = self.controller.create(req, body)
 
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(self.share)
         expected['share'].pop('snapshot_support')
         share_types.get_share_type_by_name.assert_called_once_with(
@@ -179,8 +192,11 @@ class ShareAPITest(test.TestCase):
         )
         CONF.set_default("default_share_type", self.vt['name'])
         req = fakes.HTTPRequest.blank('/shares')
+
         self.assertRaises(exception.ShareTypeNotFoundByName,
                           self.controller.create, req, {'share': self.share})
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         share_types.get_default_share_type.assert_called_once_with()
 
     def test_share_create_with_dhss_true_and_network_notexist(self):
@@ -197,8 +213,11 @@ class ShareAPITest(test.TestCase):
         )
         CONF.set_default("default_share_type", fake_share_type['name'])
         req = fakes.HTTPRequest.blank('/shares')
+
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, {'share': self.share})
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         share_types.get_default_share_type.assert_called_once_with()
 
     def test_share_create_with_share_net(self):
@@ -225,10 +244,11 @@ class ShareAPITest(test.TestCase):
         req = fakes.HTTPRequest.blank('/shares')
         res_dict = self.controller.create(req, body)
 
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
         self.assertEqual(expected, res_dict)
-        # pylint: disable=unsubscriptable-object
         self.assertEqual("fakenetid",
                          create_mock.call_args[1]['share_network_id'])
 
@@ -253,7 +273,11 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', create_mock)
         body = {"share": copy.deepcopy(shr)}
         req = fakes.HTTPRequest.blank('/shares')
+
         res_dict = self.controller.create(req, body)
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
         self.assertEqual(expected, res_dict)
@@ -291,11 +315,14 @@ class ShareAPITest(test.TestCase):
 
         body = {"share": copy.deepcopy(shr)}
         req = fakes.HTTPRequest.blank('/shares')
+
         res_dict = self.controller.create(req, body)
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
         self.assertEqual(expected, res_dict)
-        # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
                          create_mock.call_args[1]['share_network_id'])
 
@@ -332,11 +359,14 @@ class ShareAPITest(test.TestCase):
 
         body = {"share": copy.deepcopy(shr)}
         req = fakes.HTTPRequest.blank('/shares')
+
         res_dict = self.controller.create(req, body)
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
         self.assertEqual(expected, res_dict)
-        # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
                          create_mock.call_args[1]['share_network_id'])
 
@@ -353,10 +383,13 @@ class ShareAPITest(test.TestCase):
         }
         body = {"share": shr}
         req = fakes.HTTPRequest.blank('/shares')
+
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create,
                           req,
                           body)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
 
     @ddt.data("1.0", "2.0")
     def test_share_create_from_snapshot_not_supported(self, microversion):
@@ -398,10 +431,11 @@ class ShareAPITest(test.TestCase):
 
         res_dict = self.controller.create(req, body)
 
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
         self.assertDictEqual(expected, res_dict)
-        # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
                          create_mock.call_args[1]['share_network_id'])
 
@@ -417,6 +451,8 @@ class ShareAPITest(test.TestCase):
                           self.controller.create,
                           req,
                           body)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
 
     def test_share_create_no_body(self):
         body = {}
@@ -425,6 +461,8 @@ class ShareAPITest(test.TestCase):
                           self.controller.create,
                           req,
                           body)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
 
     def test_share_create_invalid_availability_zone(self):
         self.mock_object(
@@ -484,7 +522,11 @@ class ShareAPITest(test.TestCase):
         body = {"share": shr}
 
         req = fakes.HTTPRequest.blank('/share/1')
+
         res_dict = self.controller.update(req, 1, body)
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'update')
         self.assertEqual(shr["display_name"], res_dict['share']["name"])
         self.assertEqual(shr["display_description"],
                          res_dict['share']["description"])
@@ -493,7 +535,11 @@ class ShareAPITest(test.TestCase):
 
     def test_share_not_updates_size(self):
         req = fakes.HTTPRequest.blank('/share/1')
+
         res_dict = self.controller.update(req, 1, {"share": self.share})
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'update')
         self.assertNotEqual(res_dict['share']["size"], self.share["size"])
 
     def test_share_delete_no_share(self):
@@ -535,7 +581,7 @@ class ShareAPITest(test.TestCase):
             {'id': 'id3', 'display_name': 'n3'},
         ]
         self.mock_object(share_api.API, 'get_all',
-                         mock.Mock(return_value=[shares[1]]))
+                         mock.Mock(return_value=shares))
 
         result = self.controller.index(req)
 
@@ -549,10 +595,7 @@ class ShareAPITest(test.TestCase):
             'metadata': {'k1': 'v1'},
             'extra_specs': {'k2': 'v2'},
             'is_public': 'False',
-            'limit': '1',
-            'offset': '1'
         }
-
         if use_admin_context:
             search_opts_expected.update({'fake_key': 'fake_value'})
             search_opts_expected['host'] = search_opts['host']
@@ -636,7 +679,7 @@ class ShareAPITest(test.TestCase):
             {'id': 'id3', 'display_name': 'n3'},
         ]
         self.mock_object(share_api.API, 'get_all',
-                         mock.Mock(return_value=[shares[1]]))
+                         mock.Mock(return_value=shares))
 
         result = self.controller.detail(req)
 
@@ -650,8 +693,6 @@ class ShareAPITest(test.TestCase):
             'metadata': {'k1': 'v1'},
             'extra_specs': {'k2': 'v2'},
             'is_public': 'False',
-            'limit': '1',
-            'offset': '1'
         }
         if use_admin_context:
             search_opts_expected.update({'fake_key': 'fake_value'})
@@ -1011,7 +1052,7 @@ class ShareAdminActionsAPITest(test.TestCase):
     def setUp(self):
         super(ShareAdminActionsAPITest, self).setUp()
         CONF.set_default("default_share_type", None)
-        self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
+        self.flags(transport_url='rabbit://fake:fake@mqhost:5672')
         self.share_api = share_api.API()
         self.admin_context = context.RequestContext('admin', 'fake', True)
         self.member_context = context.RequestContext('fake', 'fake')
