@@ -39,6 +39,7 @@ def fake_share(**kwargs):
         'is_busy': False,
         'share_group_id': None,
         'instance': {
+            'id': 'fake_share_instance_id',
             'host': 'fakehost',
             'share_type_id': '1',
         },
@@ -61,6 +62,7 @@ def fake_share_instance(base_share=None, **kwargs):
         'host': 'fakehost',
         'share_network_id': 'fakesharenetworkid',
         'share_server_id': 'fakeshareserverid',
+        'share_type_id': '1',
     }
 
     for attr in models.ShareInstance._proxified_properties:
@@ -114,7 +116,7 @@ def fake_snapshot(create_instance=False, **kwargs):
         'name': 'fakesnapshotname',
         'share_size': 1,
         'share_proto': 'fake_proto',
-        'instance': None,
+        'instance': {},
         'share': 'fake_share',
         'aggregate_status': aggregate_status,
         'project_id': 'fakeprojectid',
@@ -153,7 +155,10 @@ def fake_snapshot_instance(base_snapshot=None, as_primitive=False, **kwargs):
         'provider_location': 'i_live_here_actually',
         'share_name': 'fakename',
         'share_id': 'fakeshareinstanceid',
-        'share_instance': {'share_id': 'fakeshareid', },
+        'share_instance': {
+            'share_id': 'fakeshareid',
+            'share_type_id': '1',
+        },
         'share_instance_id': 'fakeshareinstanceid',
         'deleted': False,
         'updated_at': datetime.datetime(2016, 3, 21, 0, 5, 58),
@@ -290,3 +295,21 @@ def fake_replica_request_spec(as_primitive=True, **kwargs):
         return request_spec
     else:
         return db_fakes.FakeModel(request_spec)
+
+
+def fake_share_server_get():
+    fake_share_server = {
+        'status': constants.STATUS_ACTIVE,
+        'updated_at': None,
+        'host': 'fake_host',
+        'share_network_id': 'fake_sn_id',
+        'share_network_name': 'fake_sn_name',
+        'project_id': 'fake_project_id',
+        'id': 'fake_share_server_id',
+        'backend_details': {
+            'security_service_active_directory': '{"name": "fake_AD"}',
+            'security_service_ldap': '{"name": "fake_LDAP"}',
+            'security_service_kerberos': '{"name": "fake_kerberos"}',
+        }
+    }
+    return fake_share_server
