@@ -38,11 +38,6 @@ class TestConnection(test.TestCase):
     def test_connect(self, connection):
         connection.connect(res_mock.FakeEMCShareDriver(), None)
 
-    @res_mock.patch_connection_init
-    def test_connect_with_ipv6(self, connection):
-        connection.connect(res_mock.FakeEMCShareDriverIPv6(),
-                           None)
-
     @res_mock.patch_connection
     def test_connect__invalid_pool_configuration(self, connection):
         f = connection.client.system.get_pool
@@ -180,6 +175,22 @@ class TestConnection(test.TestCase):
 
         connection.delete_share(None, share, share_server)
 
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_shrink_cifs_share(self, connection, mocked_input):
+        share = mocked_input['shrink_cifs_share']
+        new_size = 4 * units.Gi
+
+        connection.shrink_share(share, new_size)
+
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_shrink_nfs_share(self, connection, mocked_input):
+        share = mocked_input['shrink_nfs_share']
+        new_size = 4 * units.Gi
+
+        connection.shrink_share(share, new_size)
+
     @res_mock.mock_manila_input
     @res_mock.patch_connection
     def test_extend_cifs_share(self, connection, mocked_input):
@@ -211,6 +222,19 @@ class TestConnection(test.TestCase):
                           new_size,
                           share_server)
 
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_shrink_share_create_from_snap(self, connection, mocked_input):
+        share = mocked_input['shrink_cifs_share']
+        share_server = mocked_input['share_server']
+        new_size = 4 * units.Gi
+
+        self.assertRaises(exception.ShareShrinkingError,
+                          connection.shrink_share,
+                          share,
+                          new_size,
+                          share_server)
+
     @res_mock.mock_manila_input
     @res_mock.patch_connection
     def test_create_snapshot_from_filesystem(self, connection, mocked_input):
@@ -419,7 +443,6 @@ class TestConnection(test.TestCase):
 
     @res_mock.patch_connection
     def test_validate_port_configuration_exception(self, connection):
-
         self.assertRaises(exception.BadConfigurationException,
                           connection.validate_port_configuration,
                           ['xxxx*'])
@@ -658,3 +681,14 @@ class TestConnection(test.TestCase):
                     'vlan_id': '201'}
         connection.client.create_interface.assert_called_once_with(nas_server,
                                                                    **expected)
+
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_revert_to_snapshot(self, connection, mocked_input):
+        context = mock.Mock()
+        snapshot = mocked_input['snapshot']
+        share_access_rules = [mocked_input['nfs_rw_access'], ]
+        snapshot_access_rules = [mocked_input['nfs_rw_access'], ]
+
+        connection.revert_to_snapshot(context, snapshot, share_access_rules,
+                                      snapshot_access_rules)
