@@ -418,8 +418,10 @@ CIFS_SECURITY_SERVICE = {
     'type': 'active_directory',
     'password': 'fake_password',
     'user': 'fake_user',
+    'ou': 'fake_ou',
     'domain': 'fake_domain',
     'dns_ip': 'fake_dns_ip',
+    'server': '',
 }
 
 LDAP_SECURITY_SERVICE = {
@@ -468,6 +470,74 @@ SECUTITY_KEY_MANAGER_NVE_SUPPORT_RESPONSE_FALSE = etree.XML("""
   </results>
 """)
 
+NET_PORT_GET_RESPONSE_NO_VLAN = etree.XML("""
+  <results status="passed">
+    <attributes>
+      <net-port-info>
+        <administrative-duplex>auto</administrative-duplex>
+        <administrative-flowcontrol>full</administrative-flowcontrol>
+        <administrative-speed>auto</administrative-speed>
+        <broadcast-domain>%(domain)s</broadcast-domain>
+        <health-status>healthy</health-status>
+        <ignore-health-status>false</ignore-health-status>
+        <ipspace>%(ipspace)s</ipspace>
+        <is-administrative-auto-negotiate>true</is-administrative-auto-negotiate>
+        <is-administrative-up>true</is-administrative-up>
+        <is-operational-auto-negotiate>true</is-operational-auto-negotiate>
+        <link-status>up</link-status>
+        <mac-address>00:0c:29:fc:04:f7</mac-address>
+        <mtu>1500</mtu>
+        <mtu-admin>1500</mtu-admin>
+        <node>%(node_name)s</node>
+        <operational-duplex>full</operational-duplex>
+        <operational-flowcontrol>receive</operational-flowcontrol>
+        <operational-speed>1000</operational-speed>
+        <port>%(port)s</port>
+        <port-type>physical</port-type>
+        <role>data</role>
+      </net-port-info>
+    </attributes>
+  </results>
+""" % {'domain': BROADCAST_DOMAIN,
+       'ipspace': IPSPACE_NAME,
+       'node_name': NODE_NAME,
+       'port': PORT})
+
+NET_PORT_GET_RESPONSE = etree.XML("""
+  <results status="passed">
+    <attributes>
+      <net-port-info>
+        <administrative-duplex>auto</administrative-duplex>
+        <administrative-flowcontrol>full</administrative-flowcontrol>
+        <administrative-speed>auto</administrative-speed>
+        <health-status>healthy</health-status>
+        <ignore-health-status>false</ignore-health-status>
+        <ipspace>%(ipspace)s</ipspace>
+        <is-administrative-auto-negotiate>true</is-administrative-auto-negotiate>
+        <is-administrative-up>true</is-administrative-up>
+        <is-operational-auto-negotiate>true</is-operational-auto-negotiate>
+        <link-status>up</link-status>
+        <mac-address>00:0c:29:fc:04:f7</mac-address>
+        <mtu>1500</mtu>
+        <mtu-admin>1500</mtu-admin>
+        <node>%(node_name)s</node>
+        <operational-duplex>full</operational-duplex>
+        <operational-flowcontrol>receive</operational-flowcontrol>
+        <operational-speed>1000</operational-speed>
+        <port>%(port)s-%(vlan)s</port>
+        <port-type>vlan</port-type>
+        <role>data</role>
+        <vlan-id>%(vlan)s</vlan-id>
+        <vlan-node>%(node_name)s</vlan-node>
+        <vlan-port>%(port)s</vlan-port>
+      </net-port-info>
+    </attributes>
+  </results>
+""" % {'ipspace': IPSPACE_NAME,
+       'node_name': NODE_NAME,
+       'port': PORT,
+       'vlan': VLAN})
+
 NET_PORT_GET_ITER_RESPONSE = etree.XML("""
   <results status="passed">
     <attributes-list>
@@ -2426,7 +2496,7 @@ QOS_POLICY_GROUP_GET_ITER_RESPONSE = etree.XML("""
   <results status="passed">
     <attributes-list>
       <qos-policy-group-info>
-        <max-throughput>%(max_througput)s</max-throughput>
+        <max-throughput>%(max_throughput)s</max-throughput>
         <num-workloads>1</num-workloads>
         <policy-group>%(qos_policy_group_name)s</policy-group>
         <vserver>%(vserver)s</vserver>
@@ -2436,7 +2506,7 @@ QOS_POLICY_GROUP_GET_ITER_RESPONSE = etree.XML("""
   </results>""" % {
     'qos_policy_group_name': QOS_POLICY_GROUP_NAME,
     'vserver': VSERVER_NAME,
-    'max_througput': QOS_MAX_THROUGHPUT,
+    'max_throughput': QOS_MAX_THROUGHPUT,
 })
 
 FAKE_VOL_XML = """<volume-info>
