@@ -20,6 +20,7 @@ import copy
 import ddt
 import mock
 from oslo_log import log
+from oslo_serialization import jsonutils
 
 from manila import context
 from manila import exception
@@ -110,6 +111,25 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         self.assertRaises(exception.InvalidInput,
                           self.library._get_vserver)
 
+    def test_get_vserver_no_share_server_with_vserver_name(self):
+        fake_vserver_client = 'fake_client'
+
+        mock_vserver_exists = self.mock_object(
+            self.library._client, 'vserver_exists',
+            mock.Mock(return_value=True))
+        self.mock_object(self.library,
+                         '_get_api_client',
+                         mock.Mock(return_value=fake_vserver_client))
+
+        result_vserver, result_vserver_client = self.library._get_vserver(
+            share_server=None, vserver_name=fake.VSERVER1)
+
+        mock_vserver_exists.assert_called_once_with(
+            fake.VSERVER1
+        )
+        self.assertEqual(fake.VSERVER1, result_vserver)
+        self.assertEqual(fake_vserver_client, result_vserver_client)
+
     def test_get_vserver_no_backend_details(self):
 
         fake_share_server = copy.deepcopy(fake.SHARE_SERVER)
@@ -186,6 +206,69 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         }
         self.assertEqual(expected, result)
 
+    @ddt.data('fake', fake.IDENTIFIER)
+    def test_manage_server(self, fake_vserver_name):
+
+        self.mock_object(context,
+                         'get_admin_context',
+                         mock.Mock(return_value='fake_admin_context'))
+        mock_get_vserver_name = self.mock_object(
+            self.library, '_get_vserver_name',
+            mock.Mock(return_value=fake_vserver_name))
+
+        new_identifier, new_details = self.library.manage_server(
+            context, fake.SHARE_SERVER, fake.IDENTIFIER, {})
+
+        mock_get_vserver_name.assert_called_once_with(fake.SHARE_SERVER['id'])
+        self.assertEqual(fake_vserver_name, new_details['vserver_name'])
+        self.assertEqual(fake_vserver_name, new_identifier)
+
+    def test_get_share_server_network_info(self):
+
+        fake_vserver_client = mock.Mock()
+
+        self.mock_object(context,
+                         'get_admin_context',
+                         mock.Mock(return_value='fake_admin_context'))
+        mock_get_vserver = self.mock_object(
+            self.library, '_get_vserver',
+            mock.Mock(return_value=['fake', fake_vserver_client]))
+
+        net_interfaces = copy.deepcopy(c_fake.NETWORK_INTERFACES_MULTIPLE)
+
+        self.mock_object(fake_vserver_client,
+                         'get_network_interfaces',
+                         mock.Mock(return_value=net_interfaces))
+
+        result = self.library.get_share_server_network_info(context,
+                                                            fake.SHARE_SERVER,
+                                                            fake.IDENTIFIER,
+                                                            {})
+        mock_get_vserver.assert_called_once_with(
+            vserver_name=fake.IDENTIFIER
+        )
+        reference_allocations = []
+        for lif in net_interfaces:
+            reference_allocations.append(lif['address'])
+
+        self.assertEqual(reference_allocations, result)
+
+    @ddt.data((True, fake.IDENTIFIER),
+              (False, fake.IDENTIFIER))
+    @ddt.unpack
+    def test__verify_share_server_name(self, vserver_exists, identifier):
+
+        mock_exists = self.mock_object(self.client, 'vserver_exists',
+                                       mock.Mock(return_value=vserver_exists))
+        expected_result = identifier
+        if not vserver_exists:
+            expected_result = self.library._get_vserver_name(identifier)
+
+        result = self.library._get_correct_vserver_old_name(identifier)
+
+        self.assertEqual(result, expected_result)
+        mock_exists.assert_called_once_with(identifier)
+
     def test_handle_housekeeping_tasks(self):
 
         self.mock_object(self.client, 'prune_deleted_nfs_export_policies')
@@ -227,10 +310,15 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
 
         result = self.library.setup_server(fake.NETWORK_INFO)
 
+        ports = {}
+        for network_allocation in fake.NETWORK_INFO['network_allocations']:
+            ports[network_allocation['id']] = network_allocation['ip_address']
+
         self.assertTrue(mock_validate_network_type.called)
         self.assertTrue(mock_get_vserver_name.called)
         self.assertTrue(mock_create_vserver.called)
-        self.assertDictEqual({'vserver_name': fake.VSERVER1}, result)
+        self.assertDictEqual({'vserver_name': fake.VSERVER1,
+                              'ports': jsonutils.dumps(ports)}, result)
 
     def test_setup_server_with_error(self):
 
@@ -254,11 +342,16 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
             self.library.setup_server,
             fake.NETWORK_INFO)
 
+        ports = {}
+        for network_allocation in fake.NETWORK_INFO['network_allocations']:
+            ports[network_allocation['id']] = network_allocation['ip_address']
+
         self.assertTrue(mock_validate_network_type.called)
         self.assertTrue(mock_get_vserver_name.called)
         self.assertTrue(mock_create_vserver.called)
         self.assertDictEqual(
-            {'server_details': {'vserver_name': fake.VSERVER1}},
+            {'server_details': {'vserver_name': fake.VSERVER1,
+                                'ports': jsonutils.dumps(ports)}},
             fake_exception.detail_data)
 
     @ddt.data(
@@ -288,7 +381,8 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
 
         self.assertEqual(vserver_name, actual_result)
 
-    def test_create_vserver(self):
+    @ddt.data(None, fake.IPSPACE)
+    def test_create_vserver(self, existing_ipspace):
 
         versions = ['fake_v1', 'fake_v2']
         self.library.configuration.netapp_enabled_share_protocols = versions
@@ -296,6 +390,12 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         vserver_name = fake.VSERVER_NAME_TEMPLATE % vserver_id
         vserver_client = mock.Mock()
 
+        self.mock_object(self.library._client,
+                         'list_cluster_nodes',
+                         mock.Mock(return_value=fake.CLUSTER_NODES))
+        self.mock_object(self.library,
+                         '_get_node_data_port',
+                         mock.Mock(return_value='fake_port'))
         self.mock_object(context,
                          'get_admin_context',
                          mock.Mock(return_value='fake_admin_context'))
@@ -311,13 +411,23 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         self.mock_object(self.library,
                          '_create_ipspace',
                          mock.Mock(return_value=fake.IPSPACE))
+        get_ipspace_name_for_vlan_port = self.mock_object(
+            self.library._client,
+            'get_ipspace_name_for_vlan_port',
+            mock.Mock(return_value=existing_ipspace))
         self.mock_object(self.library, '_create_vserver_lifs')
         self.mock_object(self.library, '_create_vserver_admin_lif')
         self.mock_object(self.library, '_create_vserver_routes')
 
         self.library._create_vserver(vserver_name, fake.NETWORK_INFO)
 
-        self.library._create_ipspace.assert_called_once_with(fake.NETWORK_INFO)
+        get_ipspace_name_for_vlan_port.assert_called_once_with(
+            fake.CLUSTER_NODES[0],
+            'fake_port',
+            fake.NETWORK_INFO['segmentation_id'])
+        if not existing_ipspace:
+            self.library._create_ipspace.assert_called_once_with(
+                fake.NETWORK_INFO)
         self.library._client.create_vserver.assert_called_once_with(
             vserver_name, fake.ROOT_VOLUME_AGGREGATE, fake.ROOT_VOLUME,
             fake.AGGREGATES, fake.IPSPACE)
@@ -351,13 +461,30 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
                           vserver_name,
                           fake.NETWORK_INFO)
 
-    @ddt.data(netapp_api.NaApiError, exception.NetAppException)
-    def test_create_vserver_lif_creation_failure(self, lif_exception):
+    @ddt.data(
+        {'lif_exception': netapp_api.NaApiError,
+         'existing_ipspace': fake.IPSPACE},
+        {'lif_exception': netapp_api.NaApiError,
+         'existing_ipspace': None},
+        {'lif_exception': exception.NetAppException,
+         'existing_ipspace': None},
+        {'lif_exception': exception.NetAppException,
+         'existing_ipspace': fake.IPSPACE})
+    @ddt.unpack
+    def test_create_vserver_lif_creation_failure(self,
+                                                 lif_exception,
+                                                 existing_ipspace):
 
         vserver_id = fake.NETWORK_INFO['server_id']
         vserver_name = fake.VSERVER_NAME_TEMPLATE % vserver_id
         vserver_client = mock.Mock()
 
+        self.mock_object(self.library._client,
+                         'list_cluster_nodes',
+                         mock.Mock(return_value=fake.CLUSTER_NODES))
+        self.mock_object(self.library,
+                         '_get_node_data_port',
+                         mock.Mock(return_value='fake_port'))
         self.mock_object(context,
                          'get_admin_context',
                          mock.Mock(return_value='fake_admin_context'))
@@ -370,6 +497,9 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         self.mock_object(self.library,
                          '_find_matching_aggregates',
                          mock.Mock(return_value=fake.AGGREGATES))
+        self.mock_object(self.library._client,
+                         'get_ipspace_name_for_vlan_port',
+                         mock.Mock(return_value=existing_ipspace))
         self.mock_object(self.library,
                          '_create_ipspace',
                          mock.Mock(return_value=fake.IPSPACE))
@@ -423,27 +553,11 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
 
         self.assertEqual('Default', result)
 
-    def test_create_ipspace_already_present(self):
-
-        self.library._client.features.IPSPACES = True
-        self.mock_object(self.library._client,
-                         'ipspace_exists',
-                         mock.Mock(return_value=True))
-
-        result = self.library._create_ipspace(fake.NETWORK_INFO)
-
-        expected = self.library._get_valid_ipspace_name(
-            fake.NETWORK_INFO['neutron_subnet_id'])
-        self.assertEqual(expected, result)
-        self.library._client.ipspace_exists.assert_has_calls([
-            mock.call(expected)])
-        self.assertFalse(self.library._client.create_ipspace.called)
-
     def test_create_ipspace(self):
 
         self.library._client.features.IPSPACES = True
         self.mock_object(self.library._client,
-                         'ipspace_exists',
+                         'create_ipspace',
                          mock.Mock(return_value=False))
 
         result = self.library._create_ipspace(fake.NETWORK_INFO)
@@ -451,10 +565,7 @@ class NetAppFileStorageLibraryTestCase(test.TestCase):
         expected = self.library._get_valid_ipspace_name(
             fake.NETWORK_INFO['neutron_subnet_id'])
         self.assertEqual(expected, result)
-        self.library._client.ipspace_exists.assert_has_calls([
-            mock.call(expected)])
-        self.library._client.create_ipspace.assert_has_calls([
-            mock.call(expected)])
+        self.library._client.create_ipspace.assert_called_once_with(expected)
 
     def test_create_vserver_lifs(self):
 
