@@ -32,6 +32,7 @@ VOLUME_NAME_TEMPLATE = 'share_%(share_id)s'
 VSERVER_NAME_TEMPLATE = 'os_%s'
 AGGREGATE_NAME_SEARCH_PATTERN = '(.*)'
 SHARE_NAME = 'share_7cf7c200_d3af_4e05_b87e_9167c95dfcad'
+SHARE_INSTANCE_NAME = 'share_d24e7257_124e_4fb6_b05b_d384f660bc85'
 FLEXVOL_NAME = 'fake_volume'
 JUNCTION_PATH = '/%s' % FLEXVOL_NAME
 EXPORT_LOCATION = '%s:%s' % (HOST_NAME, JUNCTION_PATH)
@@ -44,6 +45,7 @@ SHARE_ID = '7cf7c200-d3af-4e05-b87e-9167c95dfcad'
 SHARE_ID2 = 'b51c5a31-aa5b-4254-9ee8-7d39fa4c8c38'
 SHARE_ID3 = '1379991d-037b-4897-bf3a-81b4aac72eff'
 SHARE_ID4 = '1cb41aad-fd9b-4964-8059-646f69de925e'
+SHARE_INSTANCE_ID = 'd24e7257-124e-4fb6-b05b-d384f660bc85'
 PARENT_SHARE_ID = '585c3935-2aa9-437c-8bad-5abae1076555'
 SNAPSHOT_ID = 'de4c9050-e2f9-4ce1-ade4-5ed0c9f26451'
 CONSISTENCY_GROUP_ID = '65bfa2c9-dc6c-4513-951a-b8d15b453ad8'
@@ -106,6 +108,21 @@ SHARE = {
     'encrypt': False,
 }
 
+SHARE_INSTANCE = {
+    'id': SHARE_INSTANCE_ID,
+    'share_id': SHARE_ID,
+    'host': MANILA_HOST_NAME,
+    'project_id': TENANT_ID,
+    'name': SHARE_INSTANCE_NAME,
+    'size': SHARE_SIZE,
+    'share_proto': 'fake',
+    'share_type_id': SHARE_TYPE_ID,
+    'share_network_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0',
+    'share_server_id': '7e6a2cc8-871f-4b1d-8364-5aad0f98da86',
+    'replica_state': constants.REPLICA_STATE_ACTIVE,
+    'status': constants.STATUS_AVAILABLE,
+}
+
 FLEXVOL_TO_MANAGE = {
     'aggregate': POOL_NAME,
     'junction-path': '/%s' % FLEXVOL_NAME,
@@ -171,6 +188,7 @@ PROVISIONING_OPTIONS = {
     'max_files': 5000,
     'split': True,
     'encrypt': False,
+    'hide_snapdir': False,
 }
 
 PROVISIONING_OPTIONS_WITH_QOS = copy.deepcopy(PROVISIONING_OPTIONS)
@@ -182,6 +200,7 @@ PROVISIONING_OPTIONS_BOOLEAN = {
     'dedup_enabled': False,
     'compression_enabled': False,
     'split': False,
+    'hide_snapdir': False,
 }
 
 PROVISIONING_OPTIONS_BOOLEAN_THIN_PROVISIONED_TRUE = {
@@ -266,9 +285,6 @@ REMAPPED_OVERLAPPING_EXTRA_SPEC = {
     'netapp:thin_provisioned': 'false',
 }
 
-EXTRA_SPEC_SHARE = copy.deepcopy(SHARE)
-EXTRA_SPEC_SHARE['share_type_id'] = SHARE_TYPE_ID
-
 USER_NETWORK_ALLOCATIONS = [
     {
         'id': '132dbb10-9a36-46f2-8d89-3d909830c356',
@@ -333,12 +349,14 @@ NETWORK_INFO = {
     'security_services': ['fake_ldap', 'fake_kerberos', 'fake_ad', ],
     'network_allocations': USER_NETWORK_ALLOCATIONS,
     'admin_network_allocations': ADMIN_NETWORK_ALLOCATIONS,
+    'neutron_net_id': '4eff22ca-5ad2-454d-a000-aadfd7b40b39',
     'neutron_subnet_id': '62bf1c2c-18eb-421b-8983-48a6d39aafe0',
     'segmentation_id': '1000',
 }
 NETWORK_INFO_NETMASK = '255.255.255.0'
 
 SHARE_SERVER = {
+    'id': 'fake_id',
     'share_network_id': 'c5b3a865-56d0-4d88-abe5-879965e099c9',
     'backend_details': {
         'vserver_name': VSERVER1
@@ -506,6 +524,8 @@ COLLATED_CGSNAPSHOT_INFO = [
     },
 ]
 
+IDENTIFIER = 'c5b3a865-56d0-4d88-dke5-853465e099c9'
+
 LIF_NAMES = []
 LIF_ADDRESSES = ['10.10.10.10', '10.10.10.20']
 LIFS = (
