@@ -228,6 +228,7 @@ class LVMShareDriverTestCase(test.TestCase):
         expected_exec = [
             'lvcreate -L 1G -n fakename fakevg',
             'mkfs.ext4 /dev/mapper/fakevg-fakename',
+            'e2fsck -y -f %s' % mount_share,
             'tune2fs -U random %s' % mount_share,
             ("dd count=0 if=%s of=%s iflag=direct oflag=direct" %
              (mount_snapshot, mount_share)),
@@ -333,6 +334,7 @@ class LVMShareDriverTestCase(test.TestCase):
         expected_exec = [
             ("lvcreate -L 1G --name fakesnapshotname --snapshot "
              "%s/fakename" % (CONF.lvm_share_volume_group,)),
+            "e2fsck -y -f /dev/mapper/fakevg-%s" % self.snapshot['name'],
             "tune2fs -U random /dev/mapper/fakevg-%s" % self.snapshot['name'],
             "mkdir -p " + mount_path,
             "mount /dev/mapper/fakevg-fakesnapshotname " + mount_path,
@@ -407,16 +409,16 @@ class LVMShareDriverTestCase(test.TestCase):
               (None, ['1001::1001'], [6]), (None, ['1.1.1.0'], [4]),
               (None, ['1001::1001/129', '1.1.1.0'], False))
     @ddt.unpack
-    def test_get_configured_ip_version(
+    def test_get_configured_ip_versions(
             self, configured_ip, configured_ips, configured_ip_version):
         CONF.set_default('lvm_share_export_ip', configured_ip)
         CONF.set_default('lvm_share_export_ips', configured_ips)
         if configured_ip_version:
             self.assertEqual(configured_ip_version,
-                             self._driver.get_configured_ip_version())
+                             self._driver.get_configured_ip_versions())
         else:
             self.assertRaises(exception.InvalidInput,
-                              self._driver.get_configured_ip_version)
+                              self._driver.get_configured_ip_versions)
 
     def test_mount_device(self):
         mount_path = self._get_mount_path(self.share)
@@ -579,7 +581,9 @@ class LVMShareDriverTestCase(test.TestCase):
             ("lvconvert --merge %s" % snap_lv),
             ("lvcreate -L 1G --name fakesnapshotname --snapshot %s" %
                 share_lv),
-            ('tune2fs -U random /dev/mapper/%s-fakesnapshotname' %
+            ("e2fsck -y -f /dev/mapper/%s-fakesnapshotname" %
+                CONF.lvm_share_volume_group),
+            ("tune2fs -U random /dev/mapper/%s-fakesnapshotname" %
                 CONF.lvm_share_volume_group),
             ("mkdir -p %s" % share_mount_path),
             ("mount /dev/mapper/%s-fakename %s" %
@@ -681,3 +685,11 @@ class LVMShareDriverTestCase(test.TestCase):
                           self._driver.update_share_usage_size,
                           self._context,
                           [self.share])
+
+    def test_get_backend_info(self):
+        backend_info = self._driver.get_backend_info(self._context)
+
+        self.assertEqual(
+            {'export_ips': ','.join(self.server['public_addresses']),
+             'db_version': mock.ANY},
+            backend_info)
